@@ -24,6 +24,7 @@ use warnings;
 use autodie;
 
 use List::MoreUtils qw(any);
+use Moo;
 use Text::Levenshtein qw(distance);
 
 use Lintian::Data;
@@ -31,6 +32,8 @@ use Lintian::Relation qw(:constants);
 use Lintian::Tags qw(tag);
 use Lintian::Util qw(strip);
 
+with('Lintian::Check');
+
 # If there is no debian/compat file present but cdbs is being used, cdbs will
 # create one automatically.  Currently it always uses compatibility level 5.
 # It may be better to look at what version of cdbs the package depends on and
@@ -48,8 +51,12 @@ my $compat_level = Lintian::Data->new('debhelper/compat-level',qr/=/);
 
 my $MISC_DEPENDS = Lintian::Relation->new('${misc:Depends}');
 
-sub run {
-    my (undef, undef, $info, undef, $group) = @_;
+sub source {
+    my ($self) = @_;
+
+    my $info = $self->info;
+    my $group = $self->group;
+
     my $droot = $info->index_resolved_path('debian/');
     my ($drules, $dh_bd_version, $level);
 
@@ -71,7 +78,6 @@ sub run {
         'python2' => 0,
         'python3' => 0,
         'runit'   => 0,
-        'nodejs'  => 0,
     );
     my %overrides;
 
@@ -83,6 +89,10 @@ sub run {
 
     my $command_prefix_pattern = qr/\s+[@+-]?(?:\S+=\S+\s+)*/;
 
+    foreach (qw(python2 python3)) {
+        $seen{$_} = 1 if $bdepends->implies("dh-sequence-$_");
+    }
+
     while (<$rules_fd>) {
         while (s,\\$,, and defined(my $cont = <$rules_fd>)) {
             $_ .= $cont;
@@ -94,7 +104,7 @@ sub run {
         }
 
         next if /^\s*\#/;
-        if (m/^$command_prefix_pattern(dh_\S+)/) {
+        if (m/^$command_prefix_pattern(dh_(?!autoreconf)\S+)/) {
             my $dhcommand = $1;
             $build_systems{'debhelper'} = 1
               if not exists($build_systems{'dh'});
@@ -174,9 +184,6 @@ sub run {
                     }
                 }
             }
-            if (m/--(after|before|until|remaining)/) {
-                tag 'dh-manual-sequence-control-obsolete', 'dh', $1;
-            }
         } elsif (m,^include\s+/usr/share/cdbs/1/rules/debhelper.mk,
             or m,^include\s+/usr/share/R/debian/r-cran.mk,o) {
             $build_systems{'cdbs-with-debhelper.mk'} = 1;
@@ -241,6 +248,7 @@ sub run {
                  /usr/share/pkg-kde-tools/qt-kde-team/\d+/debian-qt-kde\.mk
               }xsm
         ) {
+            $inclcdbs = 1;
             $build_systems{'dhmk'} = 1;
             delete($build_systems{'debhelper'});
         }
@@ -264,7 +272,7 @@ sub run {
         tag 'debian-build-system', 'other';
     }
 
-    unless ($seencommand) {
+    unless ($seencommand or $inclcdbs) {
         tag 'package-does-not-use-debhelper-or-cdbs';
         return;
     }
@@ -568,12 +576,6 @@ sub run {
               sort(keys %python3_depends);
         }
     }
-    if (    $seen{'nodejs'}
-        and not $overrides{'dh_auto_test'}
-        and not $seen_dh_dynamic) {
-        my $path = $info->index_resolved_path('debian/tests/pkg-js/test');
-        tag 'pkg-js-tools-test-is-missing' unless $path;
-    }
     return;
 }
 
