@@ -29,12 +29,14 @@ use autodie;
 
 use File::Basename;
 use List::MoreUtils qw(any first_index);
+use Moo;
 use Text::ParseWords qw(shellwords);
 
+use Lintian::Data;
 use Lintian::Tags qw(tag);
 use Lintian::Util qw(internal_error lstrip rstrip);
 
-use Lintian::Data;
+with('Lintian::Check');
 
 # Init scripts that do not need a service file
 my $INIT_WHITELIST = Lintian::Data->new('systemd/init-whitelist');
@@ -45,8 +47,11 @@ my $HARDENING_FLAGS = Lintian::Data->new('systemd/hardening-flags');
 # Usual WantedBy= targets
 my $WANTEDBY_WHITELIST = Lintian::Data->new('systemd/wantedby-whitelist');
 
-sub run {
-    my ($pkg, undef, $info) = @_;
+sub binary {
+    my ($self) = @_;
+
+    my $pkg = $self->package;
+    my $info = $self->info;
 
     # non-service checks
     if (my $tmpfiles = $info->index_resolved_path('etc/tmpfiles.d/')) {
@@ -87,7 +92,8 @@ sub get_init_service_name {
 sub get_init_scripts {
     my ($info) = @_;
     my @scripts;
-    if (my $initd_path = $info->index_resolved_path('etc/init.d/')) {
+    if ($info->name ne 'initscripts'
+        and my $initd_path = $info->index_resolved_path('etc/init.d/')) {
         for my $init_script ($initd_path->children) {
             # sysv generator drops the .sh suffix
             my $basename = get_init_service_name($init_script);
@@ -245,6 +251,7 @@ sub check_systemd_service_file {
           or extract_service_file_values($file, 'Install', 'RequiredBy',1)
           or extract_service_file_values($file, 'Install', 'Also',1)
           or $is_oneshot
+          or $file !~ m,^lib/systemd/[^\/]+/[^\/]+\.service$,
           or $file =~ m,@\.service$,;
         my @pidfile = extract_service_file_values($file,'Service','PIDFile',1);
         foreach my $x (@pidfile) {
